@@ -824,7 +824,7 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                    "expected:   {1}\n"
                                                    "calculated: {2}".format(i, expected, calculated))
 
-    def testTimeMovingCount(self):
+    def testTimeMovingCountRight(self):
         window = 60
         mat = TimeMovingCount(window, Latest("x"))
         values = np.random.randn(2500)
@@ -839,6 +839,51 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                    "expected:   {1}\n"
                                                    "calculated: {2}".format(i, expected, calculated))
 
+    def testTimeMovingCountBoth(self):
+        window = 60
+        mat = TimeMovingCount(window, Latest("x"), "both")
+        values = np.random.randn(2500)
+        stamps = np.cumsum(np.random.randint(0, 10, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mat.push(dict(x=value, stamp=stamp))
+
+            calculated = mat.result()
+            time_diff = (stamp - stamps) <= window
+            expected = np.sum(time_diff[:i+1])
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
+    def testTimeMovingCountLeft(self):
+        window = 60
+        mat = TimeMovingCount(window, Latest("x"), "left")
+        values = np.random.randn(2500)
+        stamps = np.cumsum(np.random.randint(0, 10, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mat.push(dict(x=value, stamp=stamp))
+
+            calculated = mat.result()
+            time_diff = (stamp - stamps) <= window
+            expected = np.sum(time_diff[:i])
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
+    def testTimeMovingCountNeither(self):
+        window = 60
+        mat = TimeMovingCount(window, Latest("x"), "neither")
+        values = np.random.randn(2500)
+        stamps = np.cumsum(np.random.randint(0, 10, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mat.push(dict(x=value, stamp=stamp))
+
+            calculated = mat.result()
+            time_diff = (stamp - stamps) < window
+            expected = np.sum(time_diff[:i])
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
     def testMovingCountUnique(self):
         window = 10
         mat = MovingCountUnique(window, Latest('x'))
@@ -855,11 +900,11 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                    "expected:   {1}\n"
                                                    "calculated: {2}".format(i, expected, calculated))
 
-    def testTimeMovingCountUnique(self):
+    def testTimeMovingCountUniqueRight(self):
         window = 60
-        mat = TimeMovingCountUnique(window, Latest("x"))
+        mat = TimeMovingCountUnique(window, Latest("x"), "right")
         values = np.random.randint(0, 10, 2500)
-        stamps = np.cumsum(np.random.randint(0, 10, 2500))
+        stamps = np.cumsum(np.random.randint(1, 10, 2500))
         for i, (value, stamp) in enumerate(zip(values, stamps)):
             mat.push(dict(x=value, stamp=stamp))
 
@@ -871,6 +916,54 @@ class TestStatefulAccumulators(unittest.TestCase):
                                                    "expected:   {1}\n"
                                                    "calculated: {2}".format(i, expected, calculated))
 
+    def testTimeMovingCountUniqueBoth(self):
+        window = 60
+        mat = TimeMovingCountUnique(window, Latest("x"), "both")
+        values = np.random.randint(0, 10, 2500)
+        stamps = np.cumsum(np.random.randint(1, 5, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mat.push(dict(x=value, stamp=stamp))
+
+            calculated = mat.result()
+            time_diff = (stamp - stamps) <= window
+            time_diff[i+1:] = False
+            expected = len(np.unique(values[time_diff]))
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
+    def testTimeMovingCountUniqueLeft(self):
+        window = 60
+        mat = TimeMovingCountUnique(window, Latest("x"), "left")
+        values = np.random.randint(0, 10, 2500)
+        stamps = np.cumsum(np.random.randint(1, 5, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mat.push(dict(x=value, stamp=stamp))
+
+            calculated = mat.result()
+            time_diff = (stamp - stamps) <= window
+            time_diff[i:] = False
+            expected = len(np.unique(values[time_diff]))
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
+    def testTimeMovingCountUniqueNeither(self):
+        window = 60
+        mat = TimeMovingCountUnique(window, Latest("x"), "neither")
+        values = np.random.randint(0, 10, 2500)
+        stamps = np.cumsum(np.random.randint(1, 5, 2500))
+        for i, (value, stamp) in enumerate(zip(values, stamps)):
+            mat.push(dict(x=value, stamp=stamp))
+
+            calculated = mat.result()
+            time_diff = (stamp - stamps) < window
+            time_diff[i:] = False
+            expected = len(np.unique(values[time_diff]))
+            self.assertEqual(calculated, expected, "at index {0}\n"
+                                                   "expected:   {1}\n"
+                                                   "calculated: {2}".format(i, expected, calculated))
+
     def testMovingAllTrue(self):
         window = 3
         underlying = Latest('x') > 0.
@@ -1613,6 +1706,34 @@ class TestStatefulAccumulators(unittest.TestCase):
         s = MovingQuantile(10, Latest('roe') + Latest('y'))
         self.assertEqual("\mathrm{MQuantile}(10, ''\\text{roe}'' + ''\\text{y}'')", str(s))
 
+    def testMovingCountStr(self):
+        s = MovingCount(10, 'roe')
+        self.assertEqual("\mathrm{MCount}(10, ''\\text{roe}'')", str(s))
+
+        s = MovingCount(10, Latest('roe') + Latest('y'))
+        self.assertEqual("\mathrm{MCount}(10, ''\\text{roe}'' + ''\\text{y}'')", str(s))
+
+    def testTimeMovingCountStr(self):
+        s = TimeMovingCount(10, 'roe')
+        self.assertEqual("\mathrm{TimeMCount}(10, ''\\text{roe}'', b'right')", str(s))
+
+        s = TimeMovingCount(10, Latest('roe') + Latest('y'))
+        self.assertEqual("\mathrm{TimeMCount}(10, ''\\text{roe}'' + ''\\text{y}'', b'right')", str(s))
+
+    def testMovingCountUniqueStr(self):
+        s = MovingCountUnique(10, 'roe')
+        self.assertEqual("\mathrm{MCountUnique}(10, ''\\text{roe}'')", str(s))
+
+        s = MovingCountUnique(10, Latest('roe') + Latest('y'))
+        self.assertEqual("\mathrm{MCountUnique}(10, ''\\text{roe}'' + ''\\text{y}'')", str(s))
+
+    def testTimeMovingCountUniqueStr(self):
+        s = TimeMovingCountUnique(10, 'roe')
+        self.assertEqual("\mathrm{TimeMCountUnique}(10, ''\\text{roe}'', b'right')", str(s))
+
+        s = TimeMovingCountUnique(10, Latest('roe') + Latest('y'))
+        self.assertEqual("\mathrm{TimeMCountUnique}(10, ''\\text{roe}'' + ''\\text{y}'', b'right')", str(s))
+
     def testMovingAllTrueStr(self):
         s = MovingAllTrue(10, 'roe')
         self.assertEqual("\mathrm{MAllTrue}(10, ''\\text{roe}'')", str(s))
